Documentation
¶
Overview ¶
Proides batch functions for interacting with batched sql statements in the same file or string.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BatchSplitCmd ¶
BatchSplitCmd takes a single command and uses separator to split them into mutliple commands.
func BatchSplitSql ¶
BatchSplitSql takes SQL text and splits it with separator.
func ExecuteBatchSql ¶
ExecuteBatchSql runs the batchSql on the connection pool on a single connection after separating out each commend, joined with separator.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.