Documentation
¶
Overview ¶
Package testcert provides utilities for generating self-signed TLS certificates for testing purposes. It can generate a root CA and derive server certificates from it, suitable for testing SQL Server TLS connections.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CA ¶
type CA struct {
Cert *x509.Certificate
PrivateKey *ecdsa.PrivateKey
CertPEM []byte
KeyPEM []byte
}
CA represents a Certificate Authority that can sign certificates.
func GenerateCA ¶
GenerateCA creates a new self-signed root Certificate Authority.
type ServerCert ¶
type ServerCert struct {
Cert *x509.Certificate
PrivateKey *ecdsa.PrivateKey
CertPEM []byte
KeyPEM []byte
CA *CA
}
ServerCert represents a server certificate signed by a CA.
Click to show internal directories.
Click to hide internal directories.